@@ -23,9 +23,13 @@ from spyderlib.widgets.tabs import Tabs
 from spyderlib.widgets.sourcecode import codeeditor
 from spyderlib.widgets.findreplace import FindReplace
 from spyderlib.plugins import SpyderPluginWidget, PluginConfigPage
+from spyderlib.py3compat import to_text_string, is_text_string
 
 
 class HistoryConfigPage(PluginConfigPage):
+    def get_icon(self):
+        return get_icon('history24.png')
+    
     def setup_page(self):
         settings_group = QGroupBox(_("Settings"))
         hist_spin = self.create_spinbox(
@@ -41,7 +45,7 @@ class HistoryConfigPage(PluginConfigPage):
                                     text=_("Font style"),
                                     fontfilters=QFontComboBox.MonospacedFonts)
         names = CONF.get('color_schemes', 'names')
-        choices = zip(names, names)
+        choices = list(zip(names, names))
         cs_combo = self.create_combobox(_("Syntax color scheme: "),
                                         choices, 'color_scheme_name')
 
@@ -154,7 +158,7 @@ class HistoryLog(SpyderPluginWidget):
         self.wrap_action.setChecked( self.get_option('wrap') )
         self.menu_actions = [history_action, font_action, self.wrap_action]
         return self.menu_actions
-    
+
     def on_first_registration(self):
         """Action to be performed on first plugin registration"""
         self.main.tabify_plugins(self.main.extconsole, self)
@@ -243,9 +247,9 @@ class HistoryLog(SpyderPluginWidget):
         Slot for SIGNAL('append_to_history(QString,QString)')
         emitted by shell instance
         """
-        if not isinstance(filename, basestring): # filename is a QString
-            filename = unicode(filename.toUtf8(), 'utf-8')
-        command = unicode(command)
+        if not is_text_string(filename): # filename is a QString
+            filename = to_text_string(filename.toUtf8(), 'utf-8')
+        command = to_text_string(command)
         index = self.filenames.index(filename)
         self.editors[index].append(command)
         if self.get_option('go_to_eof'):
