@@ -15,7 +15,6 @@ from spyderlib.qt.QtGui import (QVBoxLayout, QDialog, QWidget, QGroupBox,
 from spyderlib.qt.QtCore import SIGNAL, SLOT, Qt
 from spyderlib.qt.compat import getexistingdirectory
 
-import os
 import os.path as osp
 
 # Local imports
@@ -23,10 +22,11 @@ from spyderlib.baseconfig import _
 from spyderlib.config import CONF
 from spyderlib.utils.qthelpers import get_icon, get_std_icon
 from spyderlib.plugins.configdialog import GeneralConfigPage
+from spyderlib.py3compat import to_text_string, getcwd
 
 
-CURRENT_INTERPRETER = _("Execute in current Python or IPython interpreter")
-DEDICATED_INTERPRETER = _("Execute in a new dedicated Python interpreter")
+CURRENT_INTERPRETER = _("Execute in current Python or IPython console")
+DEDICATED_INTERPRETER = _("Execute in a new dedicated Python console")
 SYSTERM_INTERPRETER = _("Execute in an external System terminal")
 
 CURRENT_INTERPRETER_OPTION = 'default/interpreter/current'
@@ -63,11 +63,11 @@ class RunConfiguration(object):
         self.args = options.get('args', '')
         self.args_enabled = options.get('args/enabled', False)
         if CONF.get('run', WDIR_USE_FIXED_DIR_OPTION, False):
-            default_wdir = CONF.get('run', WDIR_FIXED_DIR_OPTION, os.getcwdu())
+            default_wdir = CONF.get('run', WDIR_FIXED_DIR_OPTION, getcwd())
             self.wdir = options.get('workdir', default_wdir)
             self.wdir_enabled = True
         else:
-            self.wdir = options.get('workdir', os.getcwdu())
+            self.wdir = options.get('workdir', getcwd())
             self.wdir_enabled = options.get('workdir/enabled', False)
         self.current = options.get('current',
                            CONF.get('run', CURRENT_INTERPRETER_OPTION, True))
@@ -172,7 +172,7 @@ class RunConfigOptions(QWidget):
         common_layout.addLayout(wd_layout, 1, 1)
         
         # --- Interpreter ---
-        interpreter_group = QGroupBox(_("Interpreter"))
+        interpreter_group = QGroupBox(_("Console"))
         interpreter_layout = QVBoxLayout()
         interpreter_group.setLayout(interpreter_layout)
         self.current_radio = QRadioButton(CURRENT_INTERPRETER)
@@ -183,13 +183,13 @@ class RunConfigOptions(QWidget):
         interpreter_layout.addWidget(self.systerm_radio)
         
         # --- Dedicated interpreter ---
-        new_group = QGroupBox(_("Dedicated Python interpreter"))
+        new_group = QGroupBox(_("Dedicated Python console"))
         self.connect(self.current_radio, SIGNAL("toggled(bool)"),
                      new_group.setDisabled)
         new_layout = QGridLayout()
         new_group.setLayout(new_layout)
         self.interact_cb = QCheckBox(_("Interact with the Python "
-                                       "interpreter after execution"))
+                                       "console after execution"))
         new_layout.addWidget(self.interact_cb, 1, 0, 1, -1)
         self.pclo_cb = QCheckBox(_("Command line options:"))
         new_layout.addWidget(self.pclo_cb, 2, 0)
@@ -223,9 +223,9 @@ class RunConfigOptions(QWidget):
 
     def select_directory(self):
         """Select directory"""
-        basedir = unicode(self.wd_edit.text())
+        basedir = to_text_string(self.wd_edit.text())
         if not osp.isdir(basedir):
-            basedir = os.getcwdu()
+            basedir = getcwd()
         directory = getexistingdirectory(self, _("Select directory"), basedir)
         if directory:
             self.wd_edit.setText(directory)
@@ -249,18 +249,18 @@ class RunConfigOptions(QWidget):
     
     def get(self):
         self.runconf.args_enabled = self.clo_cb.isChecked()
-        self.runconf.args = unicode(self.clo_edit.text())
+        self.runconf.args = to_text_string(self.clo_edit.text())
         self.runconf.wdir_enabled = self.wd_cb.isChecked()
-        self.runconf.wdir = unicode(self.wd_edit.text())
+        self.runconf.wdir = to_text_string(self.wd_edit.text())
         self.runconf.current = self.current_radio.isChecked()
         self.runconf.systerm = self.systerm_radio.isChecked()
         self.runconf.interact = self.interact_cb.isChecked()
         self.runconf.python_args_enabled = self.pclo_cb.isChecked()
-        self.runconf.python_args = unicode(self.pclo_edit.text())
+        self.runconf.python_args = to_text_string(self.pclo_edit.text())
         return self.runconf.get()
     
     def is_valid(self):
-        wdir = unicode(self.wd_edit.text())
+        wdir = to_text_string(self.wd_edit.text())
         if not self.wd_cb.isChecked() or osp.isdir(wdir):
             return True
         else:
@@ -368,7 +368,7 @@ class RunConfigDialog(BaseRunConfigDialog):
         
     def run_btn_clicked(self):
         """Run button was just clicked"""
-        self.file_to_run = unicode(self.combo.currentText())
+        self.file_to_run = to_text_string(self.combo.currentText())
         
     def setup(self, fname):
         """Setup Run Configuration dialog with filename *fname*"""
@@ -408,7 +408,7 @@ class RunConfigDialog(BaseRunConfigDialog):
         """Reimplement Qt method"""
         configurations = []
         for index in range(self.stack.count()):
-            filename = unicode(self.combo.itemText(index))
+            filename = to_text_string(self.combo.itemText(index))
             runconfigoptions = self.stack.widget(index)
             if index == self.stack.currentIndex() and\
                not runconfigoptions.is_valid():
@@ -422,11 +422,9 @@ class RunConfigDialog(BaseRunConfigDialog):
 class RunConfigPage(GeneralConfigPage):
     """Default Run Settings configuration page"""
     CONF_SECTION = "run"
-    def get_name(self):
-        return _("Run")
-    
-    def get_icon(self):
-        return get_icon("run.png")
+
+    NAME = _("Run")
+    ICON = "run.png"
     
     def setup_page(self):
         run_dlg = _("Run Settings")
@@ -437,7 +435,7 @@ class RunConfigPage(GeneralConfigPage):
                                ) % (run_dlg, run_dlg, run_menu))
         about_label.setWordWrap(True)
 
-        interpreter_group = QGroupBox(_("Interpreter"))
+        interpreter_group = QGroupBox(_("Console"))
         interpreter_bg = QButtonGroup(interpreter_group)
         self.current_radio = self.create_radiobutton(CURRENT_INTERPRETER,
                                 CURRENT_INTERPRETER_OPTION, True,
@@ -465,8 +463,7 @@ class RunConfigPage(GeneralConfigPage):
         thisdir_radio = self.create_radiobutton(_("the following directory:"),
                                 WDIR_USE_FIXED_DIR_OPTION, False,
                                 button_group=wdir_bg)
-        thisdir_bd = self.create_browsedir("", WDIR_FIXED_DIR_OPTION,
-                                           os.getcwdu())
+        thisdir_bd = self.create_browsedir("", WDIR_FIXED_DIR_OPTION, getcwd())
         self.connect(thisdir_radio, SIGNAL("toggled(bool)"),
                      thisdir_bd.setEnabled)
         self.connect(dirname_radio, SIGNAL("toggled(bool)"),
