@@ -13,24 +13,26 @@ NumPy Array Editor Dialog based on Qt
 # pylint: disable=R0911
 # pylint: disable=R0201
 
+from __future__ import print_function
+
 from spyderlib.qt.QtGui import (QHBoxLayout, QColor, QTableView, QItemDelegate,
                                 QLineEdit, QCheckBox, QGridLayout,
                                 QDoubleValidator, QDialog, QDialogButtonBox,
                                 QMessageBox, QPushButton, QInputDialog, QMenu,
                                 QApplication, QKeySequence, QLabel, QComboBox,
-                                QStackedWidget, QWidget, QVBoxLayout)
+                                QSpinBox, QStackedWidget, QWidget, QVBoxLayout)
 from spyderlib.qt.QtCore import (Qt, QModelIndex, QAbstractTableModel, SIGNAL,
                                  SLOT)
 from spyderlib.qt.compat import to_qvariant, from_qvariant
 
 import numpy as np
-import StringIO
 
 # Local imports
 from spyderlib.baseconfig import _
 from spyderlib.guiconfig import get_font
 from spyderlib.utils.qthelpers import (add_actions, create_action, keybinding,
                                        qapplication, get_icon)
+from spyderlib.py3compat import io, to_text_string, is_text_string
 
 # Note: string and unicode data types will be formatted with '%s' (see below)
 SUPPORTED_FORMATS = {
@@ -85,7 +87,7 @@ def is_number(dtype):
 
 def get_idx_rect(index_list):
     """Extract the boundaries from a list of indexes"""
-    rows, cols = zip(*[(i.row(), i.column()) for i in index_list])
+    rows, cols = list(zip(*[(i.row(), i.column()) for i in index_list]))
     return ( min(rows), max(rows), min(cols), max(cols) )
 
 
@@ -205,7 +207,7 @@ class ArrayModel(QAbstractTableModel):
         elif self._data.dtype.name.startswith("string"):
             val = str(value)
         elif self._data.dtype.name.startswith("unicode"):
-            val = unicode(value)
+            val = to_text_string(value)
         else:
             if value.lower().startswith('e') or value.lower().endswith('e'):
                 return False
@@ -213,14 +215,14 @@ class ArrayModel(QAbstractTableModel):
                 val = complex(value)
                 if not val.imag:
                     val = val.real
-            except ValueError, e:
+            except ValueError as e:
                 QMessageBox.critical(self.dialog, "Error",
                                      "Value error: %s" % str(e))
                 return False
         try:
             self.test_array[0] = val # will raise an Exception eventually
-        except OverflowError, e:
-            print type(e.message)
+        except OverflowError as e:
+            print(type(e.message))
             QMessageBox.critical(self.dialog, "Error",
                                  "Overflow error: %s" % e.message)
             return False
@@ -298,7 +300,7 @@ class ArrayView(QTableView):
         self.setModel(model)
         self.setItemDelegate(ArrayDelegate(dtype, self))
         total_width = 0
-        for k in xrange(shape[1]):
+        for k in range(shape[1]):
             total_width += self.columnWidth(k)
         self.viewport().resize(min(total_width, 1024), self.height())
         self.shape = shape
@@ -347,7 +349,7 @@ class ArrayView(QTableView):
         """Copy an array portion to a unicode string"""
         row_min, row_max, col_min, col_max = get_idx_rect(cell_range)
         _data = self.model().get_data()
-        output = StringIO.StringIO()
+        output = io.StringIO()
         np.savetxt(output,
                   _data[row_min:row_max+1, col_min:col_max+1],
                   delimiter='\t')
@@ -403,7 +405,7 @@ class ArrayEditorWidget(QWidget):
         
     def accept_changes(self):
         """Accept changes"""
-        for (i, j), value in self.model.changes.iteritems():
+        for (i, j), value in list(self.model.changes.items()):
             self.data[i, j] = value
         if self.old_data_shape is not None:
             self.data.shape = self.old_data_shape
@@ -444,7 +446,10 @@ class ArrayEditor(QDialog):
         self.arraywidget = None
         self.stack = None
         self.layout = None
-    
+        # Values for 3d array editor
+        self.dim_indexes = [{}, {}, {}]
+        self.last_dim = 0  # Adjust this for changing the startup dimension
+        
     def setup_and_check(self, data, title='', readonly=False,
                         xlabels=None, ylabels=None):
         """
@@ -457,8 +462,8 @@ class ArrayEditor(QDialog):
         if data.size == 0:
             self.error(_("Array is empty"))
             return False
-        if data.ndim > 2:
-            self.error(_("Arrays with more than 2 dimensions "
+        if data.ndim > 3:
+            self.error(_("Arrays with more than 3 dimensions "
                                "are not supported"))
             return False
         if xlabels is not None and len(xlabels) != self.data.shape[1]:
@@ -471,7 +476,7 @@ class ArrayEditor(QDialog):
             return False
         if not is_record_array:
             dtn = data.dtype.name
-            if dtn not in SUPPORTED_FORMATS and not dtn.startswith('string') \
+            if dtn not in SUPPORTED_FORMATS and not dtn.startswith('str') \
                and not dtn.startswith('unicode'):
                 arr = _("%s arrays") % data.dtype.name
                 self.error(_("%s are currently not supported") % arr)
@@ -481,7 +486,7 @@ class ArrayEditor(QDialog):
         self.setLayout(self.layout)
         self.setWindowIcon(get_icon('arredit.png'))
         if title:
-            title = unicode(title) # in case title is not a string
+            title = to_text_string(title) # in case title is not a string
         else:
             title = _("Array editor")
         if readonly:
@@ -502,6 +507,8 @@ class ArrayEditor(QDialog):
                                                    xlabels, ylabels))
             self.stack.addWidget(ArrayEditorWidget(self, data.mask, readonly,
                                                    xlabels, ylabels))
+        elif data.ndim == 3:
+            pass
         else:
             self.stack.addWidget(ArrayEditorWidget(self, data, readonly,
                                                    xlabels, ylabels))
@@ -512,7 +519,7 @@ class ArrayEditor(QDialog):
 
         # Buttons configuration
         btn_layout = QHBoxLayout()
-        if is_record_array or is_masked_array:
+        if is_record_array or is_masked_array or data.ndim == 3:
             if is_record_array:
                 btn_layout.addWidget(QLabel(_("Record array fields:")))
                 names = []
@@ -521,17 +528,42 @@ class ArrayEditor(QDialog):
                     text = name
                     if len(field) >= 3:
                         title = field[2]
-                        if not isinstance(title, basestring):
+                        if not is_text_string(title):
                             title = repr(title)
                         text += ' - '+title
                     names.append(text)
             else:
                 names = [_('Masked data'), _('Data'), _('Mask')]
-            ra_combo = QComboBox(self)
-            self.connect(ra_combo, SIGNAL('currentIndexChanged(int)'),
-                         self.stack.setCurrentIndex)
-            ra_combo.addItems(names)
-            btn_layout.addWidget(ra_combo)
+            if data.ndim == 3:
+                # QSpinBox
+                self.index_spin = QSpinBox(self, keyboardTracking=False)
+                self.connect(self.index_spin, SIGNAL('valueChanged(int)'),
+                             self.change_active_widget)
+                # QComboBox
+                names = [str(i) for i in range(3)]
+                ra_combo = QComboBox(self)
+                ra_combo.addItems(names)
+                self.connect(ra_combo, SIGNAL('currentIndexChanged(int)'),
+                             self.current_dim_changed)    
+                # Adding the widgets to layout
+                label = QLabel(_("Axis:"))
+                btn_layout.addWidget(label)
+                btn_layout.addWidget(ra_combo)
+                self.shape_label = QLabel()
+                btn_layout.addWidget(self.shape_label)
+                label = QLabel(_("Index:"))
+                btn_layout.addWidget(label)
+                btn_layout.addWidget(self.index_spin)
+                self.slicing_label = QLabel()
+                btn_layout.addWidget(self.slicing_label)
+                # set the widget to display when launched
+                self.current_dim_changed(self.last_dim)
+            else:
+                ra_combo = QComboBox(self)
+                self.connect(ra_combo, SIGNAL('currentIndexChanged(int)'),
+                             self.stack.setCurrentIndex)
+                ra_combo.addItems(names)
+                btn_layout.addWidget(ra_combo)
             if is_masked_array:
                 label = QLabel(_("<u>Warning</u>: changes are applied separately"))
                 label.setToolTip(_("For performance reasons, changes applied "\
@@ -544,17 +576,61 @@ class ArrayEditor(QDialog):
         self.connect(bbox, SIGNAL("rejected()"), SLOT("reject()"))
         btn_layout.addWidget(bbox)
         self.layout.addLayout(btn_layout, 2, 0)
-        
+
         self.setMinimumSize(400, 300)
         
         # Make the dialog act as a window
         self.setWindowFlags(Qt.Window)
         
         return True
-        
+            
     def current_widget_changed(self, index):
-        self.arraywidget = self.stack.widget(index)
-        
+        self.arraywidget = self.stack.widget(index)     
+            
+    def change_active_widget(self, index):
+        """
+        This is implemented for handling negative values in index for
+        3d arrays, to give the same behavior as slicing
+        """
+        string_index = [':']*3
+        string_index[self.last_dim] = '<font color=red>%i</font>'
+        self.slicing_label.setText((r"Slicing: [" + ", ".join(string_index) +
+                                "]") % index)
+        if index < 0:
+            data_index = self.data.shape[self.last_dim] + index
+        else:
+            data_index = index
+        slice_index = [slice(None)]*3
+        slice_index[self.last_dim] = data_index
+
+        stack_index = self.dim_indexes[self.last_dim].get(data_index)
+        if stack_index == None:
+            stack_index = self.stack.count()
+            self.stack.addWidget(ArrayEditorWidget(self,
+                                                   self.data[slice_index]))
+            self.dim_indexes[self.last_dim][data_index] = stack_index
+            self.stack.update()
+        self.stack.setCurrentIndex(stack_index)
+
+    def current_dim_changed(self, index):
+        """
+        This change the active axis the array editor is plotting over
+        in 3D
+        """
+        self.last_dim = index
+        string_size = ['%i']*3
+        string_size[index] = '<font color=red>%i</font>'
+        self.shape_label.setText(('Shape: (' + ', '.join(string_size) +
+                                 ')    ') % self.data.shape)
+        if self.index_spin.value() != 0:
+            self.index_spin.setValue(0)
+        else:
+            # this is done since if the value is currently 0 it does not emit
+            # currentIndexChanged(int)
+            self.change_active_widget(0)
+        self.index_spin.setRange(-self.data.shape[index],
+                                 self.data.shape[index]-1)
+
     def accept(self):
         """Reimplement Qt method"""
         for index in range(self.stack.count()):
@@ -598,33 +674,39 @@ def test():
     _app = qapplication()
     
     arr = np.array(["kjrekrjkejr"])
-    print "out:", test_edit(arr, "string array")
-    arr = np.array([u"kjrekrjkejr"])
-    print "out:", test_edit(arr, "unicode array")
+    print("out:", test_edit(arr, "string array"))
+    from spyderlib.py3compat import u
+    arr = np.array([u("kjrekrjkejr")])
+    print("out:", test_edit(arr, "unicode array"))
     arr = np.ma.array([[1, 0], [1, 0]], mask=[[True, False], [False, False]])
-    print "out:", test_edit(arr, "masked array")
-    arr = np.zeros((2,2), {'names': ('red', 'green', 'blue'),
+    print("out:", test_edit(arr, "masked array"))
+    arr = np.zeros((2, 2), {'names': ('red', 'green', 'blue'),
                            'formats': (np.float32, np.float32, np.float32)})
-    print "out:", test_edit(arr, "record array")
+    print("out:", test_edit(arr, "record array"))
     arr = np.array([(0, 0.0), (0, 0.0), (0, 0.0)],
                    dtype=[(('title 1', 'x'), '|i1'),
                           (('title 2', 'y'), '>f4')])
-    print "out:", test_edit(arr, "record array with titles")
+    print("out:", test_edit(arr, "record array with titles"))
     arr = np.random.rand(5, 5)
-    print "out:", test_edit(arr, "float array",
-                            xlabels=['a', 'b', 'c', 'd', 'e'])
+    print("out:", test_edit(arr, "float array",
+                            xlabels=['a', 'b', 'c', 'd', 'e']))
     arr = np.round(np.random.rand(5, 5)*10)+\
                    np.round(np.random.rand(5, 5)*10)*1j
-    print "out:", test_edit(arr, "complex array",
+    print("out:", test_edit(arr, "complex array",
                             xlabels=np.linspace(-12, 12, 5),
-                            ylabels=np.linspace(-12, 12, 5))
+                            ylabels=np.linspace(-12, 12, 5)))
     arr_in = np.array([True, False, True])
-    print "in:", arr_in
+    print("in:", arr_in)
     arr_out = test_edit(arr_in, "bool array")
-    print "out:", arr_out
-    print arr_in is arr_out
+    print("out:", arr_out)
+    print(arr_in is arr_out)
     arr = np.array([1, 2, 3], dtype="int8")
-    print "out:", test_edit(arr, "int array")
+    print("out:", test_edit(arr, "int array"))
+    arr = np.zeros((3,3,4))
+    arr[0,0,0]=1
+    arr[0,0,1]=2
+    arr[0,0,2]=3
+    print("out:", test_edit(arr))
 
 
 if __name__ == "__main__":
