@@ -25,9 +25,11 @@ from spyderlib.qt.QtGui import (QMessageBox, QTableView, QItemDelegate,
 from spyderlib.qt.QtCore import (Qt, QModelIndex, QAbstractTableModel, SIGNAL,
                                  SLOT, QDateTime, Signal)
 from spyderlib.qt.compat import to_qvariant, from_qvariant, getsavefilename
+from spyderlib.utils.qthelpers import mimedata2url
 
 import sys
 import datetime
+import os
 
 # Local import
 from spyderlib.baseconfig import _
@@ -39,12 +41,15 @@ from spyderlib.widgets.dicteditorutils import (sort_against, get_size,
                get_human_readable_type, value_to_display, get_color_name,
                is_known_type, FakeObject, Image, ndarray, array, MaskedArray,
                unsorted_unique, try_to_eval, datestr_to_datetime,
-               get_numpy_dtype, is_editable_type)
+               get_numpy_dtype, is_editable_type, DataFrame, TimeSeries)
 if ndarray is not FakeObject:
     from spyderlib.widgets.arrayeditor import ArrayEditor
+if DataFrame is not FakeObject:
+    from spyderlib.widgets.dataframeeditor import DataFrameEditor
 from spyderlib.widgets.texteditor import TextEditor
 from spyderlib.widgets.importwizard import ImportWizard
 from spyderlib.py3compat import to_text_string, is_text_string, getcwd, u
+from spyderlib.utils.iofuncs import iofunctions
 
 
 def display_to_value(value, default_value, ignore_errors=True):
@@ -399,6 +404,16 @@ class DictDelegate(QItemDelegate):
                                             key=key, readonly=readonly,
                                             conv=conv_func))
             return None
+        #--editor = DataFrameEditor and TimeSeriesEditor
+        elif isinstance(value, (DataFrame, TimeSeries))\
+             and DataFrame is not FakeObject:
+            editor = DataFrameEditor()
+            if not editor.setup_and_check(value):
+                return	
+            self.create_dialog(editor, dict(model=index.model(), editor=editor,
+                                            key=key, readonly=readonly))
+            return None
+
         #---editor = QDateTimeEdit
         elif isinstance(value, datetime.datetime) and not self.inplace:
             editor = QDateTimeEdit(value, parent)
@@ -516,6 +531,8 @@ class DictDelegate(QItemDelegate):
 class BaseTableView(QTableView):
     """Base dictionnary editor table view"""
     sig_option_changed = Signal(str, object)
+    sig_files_dropped = Signal(list)
+    
     def __init__(self, parent):
         QTableView.__init__(self, parent)
         self.array_filename = None
@@ -537,6 +554,7 @@ class BaseTableView(QTableView):
         self.rename_action = None
         self.duplicate_action = None
         self.delegate = None
+        self.setAcceptDrops(True)
         
     def setup_table(self):
         """Setup table"""
@@ -745,7 +763,10 @@ class BaseTableView(QTableView):
         """Reimplement Qt method"""
         index_clicked = self.indexAt(event.pos())
         if index_clicked.isValid():
-            self.edit_item()
+            row = index_clicked.row()
+            # TODO: Remove hard coded "Value" column number (3 here)
+            index_clicked = index_clicked.child(row, 3)
+            self.edit(index_clicked)
         else:
             event.accept()
     
@@ -772,6 +793,31 @@ class BaseTableView(QTableView):
             self.empty_ws_menu.popup(event.globalPos())
             event.accept()
 
+    def dragEnterEvent(self, event):
+        """Allow user to drag files"""
+        if mimedata2url(event.mimeData()):
+            event.accept()
+        else:
+            event.ignore()
+    
+    def dragMoveEvent(self, event):
+        """Allow user to move files"""
+        if mimedata2url(event.mimeData()):
+            event.setDropAction(Qt.CopyAction)
+            event.accept()
+        else:
+            event.ignore()
+
+    def dropEvent(self, event):
+        """Allow user to drop supported files"""
+        urls = mimedata2url(event.mimeData())
+        if urls:
+            event.setDropAction(Qt.CopyAction)
+            event.accept()
+            self.sig_files_dropped.emit(urls)
+        else:
+            event.ignore()
+
     def toggle_inplace(self, state):
         """Toggle in-place editor option"""
         self.sig_option_changed.emit('inplace', state)
@@ -1202,6 +1248,7 @@ class RemoteDictEditorTableView(BaseTableView):
                  is_array_func=None, is_image_func=None, is_dict_func=None,
                  get_array_shape_func=None, get_array_ndim_func=None,
                  oedit_func=None, plot_func=None, imshow_func=None,
+                 is_data_frame_func=None, is_time_series_func=None,
                  show_image_func=None):
         BaseTableView.__init__(self, parent)
         
@@ -1210,7 +1257,9 @@ class RemoteDictEditorTableView(BaseTableView):
         self.remove_values = remove_values_func
         self.copy_value = copy_value_func
         self.new_value = new_value_func
-        
+
+        self.is_data_frame = is_data_frame_func
+        self.is_time_series = is_time_series_func
         self.is_list = is_list_func
         self.get_len = get_len_func
         self.is_array = is_array_func
@@ -1266,7 +1315,8 @@ class RemoteDictEditorTableView(BaseTableView):
 
     def oedit_possible(self, key):
         if (self.is_list(key) or self.is_dict(key) 
-            or self.is_array(key) or self.is_image(key)):
+            or self.is_array(key) or self.is_image(key)
+            or self.is_data_frame(key) or self.is_time_series(key)):
             # If this is a remote dict editor, the following avoid 
             # transfering large amount of data through the socket
             return True
@@ -1359,4 +1409,4 @@ def remote_editor_test():
         print(dialog.get_value())
 
 if __name__ == "__main__":
-    test()
\ No newline at end of file
+    test()
