@@ -13,7 +13,7 @@ import socket
 
 from spyderlib.qt.QtGui import QApplication, QMessageBox, QSplitter, QMenu
 from spyderlib.qt.QtCore import QProcess, SIGNAL, Qt, QTextCodec
-locale_codec = QTextCodec.codecForLocale()
+LOCALE_CODEC = QTextCodec.codecForLocale()
 from spyderlib.qt.compat import getexistingdirectory
 
 # Local imports
@@ -26,10 +26,11 @@ from spyderlib.utils.misc import get_python_executable
 from spyderlib.baseconfig import _, get_module_source_path, DEBUG
 from spyderlib.widgets.shell import PythonShellWidget
 from spyderlib.widgets.externalshell.namespacebrowser import NamespaceBrowser
-from spyderlib.widgets.externalshell.monitor import communicate, write_packet
+from spyderlib.utils.bsdsocket import communicate, write_packet
 from spyderlib.widgets.externalshell.baseshell import (ExternalShellBase,
                                                    add_pathlist_to_PYTHONPATH)
 from spyderlib.widgets.dicteditor import DictEditor
+from spyderlib.py3compat import is_text_string, to_text_string
 
 
 class ExtPythonShellWidget(PythonShellWidget):
@@ -107,7 +108,7 @@ class ExtPythonShellWidget(PythonShellWidget):
         return self.ask_monitor("__get__doc____('%s')" % objtxt)
     
     def get_doc(self, objtxt):
-        """Get object documentation"""
+        """Get object documentation dictionary"""
         return self.ask_monitor("__get_doc__('%s')" % objtxt)
     
     def get_source(self, objtxt):
@@ -157,13 +158,13 @@ class ExternalPythonShell(ExternalShellBase):
                  ipykernel=False, arguments='', stand_alone=None,
                  umd_enabled=True, umd_namelist=[], umd_verbose=True,
                  pythonstartup=None, pythonexecutable=None,
-                 monitor_enabled=True, mpl_patch_enabled=True,
-                 mpl_backend=None, ets_backend='qt4', qt_api=None, pyqt_api=0,
-                 install_qt_inputhook=True, ignore_sip_setapi_errors=False,
-                 merge_output_channels=False, colorize_sys_stderr=False,
-                 autorefresh_timeout=3000, autorefresh_state=True,
-                 light_background=True, menu_actions=None,
-                 show_buttons_inside=True, show_elapsed_time=True):
+                 monitor_enabled=True, mpl_backend=None, ets_backend='qt4',
+                 qt_api=None, pyqt_api=0, install_qt_inputhook=True,
+                 ignore_sip_setapi_errors=False, merge_output_channels=False,
+                 colorize_sys_stderr=False, autorefresh_timeout=3000,
+                 autorefresh_state=True, light_background=True,
+                 menu_actions=None, show_buttons_inside=True,
+                 show_elapsed_time=True):
 
         assert qt_api in (None, 'pyqt', 'pyside')
 
@@ -172,10 +173,11 @@ class ExternalPythonShell(ExternalShellBase):
         self.dialog_manager = DialogManager()
         
         self.stand_alone = stand_alone # stand alone settings (None: plugin)
+        self.interact = interact
+        self.is_ipykernel = ipykernel
         self.pythonstartup = pythonstartup
         self.pythonexecutable = pythonexecutable
         self.monitor_enabled = monitor_enabled
-        self.mpl_patch_enabled = mpl_patch_enabled
         self.mpl_backend = mpl_backend
         self.ets_backend = ets_backend
         self.qt_api = qt_api
@@ -199,7 +201,7 @@ class ExternalPythonShell(ExternalShellBase):
         self.notification_thread = None
         
         ExternalShellBase.__init__(self, parent=parent, fname=fname, wdir=wdir,
-                                   history_filename='.history.py',
+                                   history_filename='history.py',
                                    light_background=light_background,
                                    menu_actions=menu_actions,
                                    show_buttons_inside=show_buttons_inside,
@@ -210,16 +212,16 @@ class ExternalPythonShell(ExternalShellBase):
 
         self.python_args = None
         if python_args:
-            assert isinstance(python_args, basestring)
+            assert is_text_string(python_args)
             self.python_args = python_args
         
-        assert isinstance(arguments, basestring)
+        assert is_text_string(arguments)
         self.arguments = arguments
         
         self.connection_file = None
-        self.is_ipykernel = ipykernel
+
         if self.is_ipykernel:
-            interact = False
+            self.interact = False
             # Running our custom startup script for IPython kernels:
             # (see spyderlib/widgets/externalshell/start_ipython_kernel.py)
             self.fname = get_module_source_path(
@@ -228,7 +230,7 @@ class ExternalPythonShell(ExternalShellBase):
         self.shell.set_externalshell(self)
 
         self.toggle_globals_explorer(False)
-        self.interact_action.setChecked(interact)
+        self.interact_action.setChecked(self.interact)
         self.debug_action.setChecked(debug)
         
         self.introspection_socket = None
@@ -402,8 +404,8 @@ The process may not exit as a result of clicking this button
                                   self.debug_action.isChecked(),
                                   self.arguments)
         
-        env = [unicode(_path) for _path in self.process.systemEnvironment()]
-
+        env = [to_text_string(_path)
+               for _path in self.process.systemEnvironment()]
         if self.pythonstartup:
             env.append('PYTHONSTARTUP=%s' % self.pythonstartup)
         
@@ -437,7 +439,6 @@ The process may not exit as a result of clicking this button
         
         # External modules options
         env.append('ETS_TOOLKIT=%s' % self.ets_backend)
-        env.append('MATPLOTLIB_PATCH=%r' % self.mpl_patch_enabled)
         if self.mpl_backend:
             env.append('MATPLOTLIB_BACKEND=%s' % self.mpl_backend)
         if self.qt_api:
@@ -459,6 +460,12 @@ The process may not exit as a result of clicking this button
             env.append('UMD_ENABLED=%r' % self.umd_enabled)
             env.append('UMD_NAMELIST=%s' % ','.join(self.umd_namelist))
             env.append('UMD_VERBOSE=%r' % self.umd_verbose)
+            env.append('MATPLOTLIB_ION=True')
+        else:
+            if self.interact:
+                env.append('MATPLOTLIB_ION=True')
+            else:
+                env.append('MATPLOTLIB_ION=False')
 
         # IPython kernel
         env.append('IPYTHON_KERNEL=%r' % self.is_ipykernel)
@@ -517,16 +524,23 @@ The process may not exit as a result of clicking this button
         running = self.process.waitForStarted(3000)
         self.set_running_state(running)
         if not running:
-            QMessageBox.critical(self, _("Error"),
-                             _("A Python or IPython Console failed to start!"))
+            if self.is_ipykernel:
+                self.emit(SIGNAL("ipython_kernel_start_error(QString)"),
+                          _("The kernel failed to start!! That's all we know... "
+                            "Please close this console and open a new one."))
+            else:
+                QMessageBox.critical(self, _("Error"),
+                                     _("A Python console failed to start!"))
         else:
             self.shell.setFocus()
             self.emit(SIGNAL('started()'))
-            
         return self.process
 
     def finished(self, exit_code, exit_status):
         """Reimplement ExternalShellBase method"""
+        if self.is_ipykernel and exit_code == 1:
+            self.emit(SIGNAL("ipython_kernel_start_error(QString)"),
+                      self.shell.get_text_with_eol())
         ExternalShellBase.finished(self, exit_code, exit_status)
         self.introspection_socket = None
 
@@ -548,8 +562,8 @@ The process may not exit as a result of clicking this button
         if not self.is_running():
             return
             
-        if not isinstance(text, basestring):
-            text = unicode(text)
+        if not is_text_string(text):
+            text = to_text_string(text)
         if self.install_qt_inputhook and self.introspection_socket is not None:
             communicate(self.introspection_socket,
                         "toggle_inputhook_flag(True)")
@@ -560,7 +574,7 @@ The process may not exit as a result of clicking this button
             text = 'evalsc(r"%s")\n' % text
         if not text.endswith('\n'):
             text += '\n'
-        self.process.write(locale_codec.fromUnicode(text))
+        self.process.write(LOCALE_CODEC.fromUnicode(text))
         self.process.waitForBytesWritten(-1)
         
         # Eventually write prompt faster (when hitting Enter continuously)
